Raw numeric Non-XBRL
====================

Numbers extracted from non-XBRL sections of 10-K/Q, earnings press-releases and 8-K

.. automodule:: calcbench.raw_numeric_non_XBRL
    :members:
    :undoc-members: